<?php
/**
 * Main file of IronCMS - loads other files
 * 
 * @package Iron CMS
 * @author Sobak
 * @version 1.2
 */
error_reporting(E_ALL & ~E_NOTICE);

/**
 * Buffering is necessary;
 * create an object of core class
 */
ob_start();
require_once 'core.class.php';
$core = new core;

/**
 * Start debug. Total script time and queries counter
 * It will show in theme's footer.php file
 */
$scriptTimeStart = microtime(true);

/**
 * Load main modules
 */
$core->loadModule('db.class');
$core->loadModule('user.class');

/**
 * Connect to database
 */
db::connect();

/**
 * Set necessary variables and do other important things :P
 */
define('THEME', $core->getTheme());

if (user::isLogged ()) {
    $user = user::getData('', '');
}

/**
 * URL routing section
 * explode address by slash
 */
$addr = $core->splitAddr($_SERVER['QUERY_STRING']);
//$addr = $core->splitAddr($_GET['path']);


/**
 * Save the first element of an address to the variable $id
 */
$id = $addr[0];

/**
 * Load theme's functions
 */
if (file_exists('themes/'.THEME.'/functions.php')) {
    require_once 'themes/'.THEME.'/functions.php';
}

else {
    logger::addEvent (2, __FILE__, __LINE__, "Theme's functions.php file doesn't exists");
}

/**
 * If $id is empty, then set it to default value
 */
if (empty ($id) or !isset($id)) {
    $home_id = core::getSetting('home_id'); // Get id of page shows as a main page

    if ($home_id == '') { // If $home_id isn't set, then use "main_page" ID (default)
     $id = 'main_page';
    }

    else {
     $id = $home_id;
     }
    
}


/**
 * Check whether page exists
 * and if it's not in trash
 */
if ($core->pageExists($id)) {
    $content = $core->pageReturnData($id);
    
    if ($content['page_type'] == '2') {
        // Current page has content in *.php file. Check whether exists and set $isInWebs to true.
        if (!file_exists("webs/$id.php")) {            
            logger::addEvent(1, __FILE__, __LINE__, 'Dane o stronie istnieją w bazie, ale nie znaleziono pliku '.$id.'.php');
            core::redirect('?error_404');
        }
    }
}

else {
    header('HTTP/1.1 404 Not Found');
    $content = core::pageReturnData('error_404');
}

/**
 * If page's type is 2 (content generated by PHP file), then set $isInWebs as true
 */
if ($content['page_type'] == 2) $isInWebs = true;

/**
 * Load header file
 */
$core->loadModule('nbbc'); // Load NBBC parser
$core->loadModule('seo'); // Load SEO module - individual keywords, description etc
require_once 'themes/'.THEME.'/header.php'; // Load theme's header


/**
 * If page with that id is *.php file, then include it!
 */
if ($isInWebs == true) {
 require ('webs/'.$id.'.php');
}

/**
 * Else show page content from database
 */
else {
    $bbc = core::bbcodePrepareParser();
    echo $bbc->Parse($content['content']);


 // Comments "engine"
 $core->loadModule('comments.class');
 comments::show ();
 comments::form ();

}

 require_once 'themes/'.THEME.'/footer.php'; // Include theme's footer

 ob_end_flush ();
?>